@@ -19,10 +19,10 @@ from tqdm import tqdm
 # For white noise strategy
 from random import choice
 
-from quantbacktest._helper_functions import find_dataframe_value_with_keywords, \
-    find_price, calculate_portfolio_value, calculate_relative_gross_exposure
-from quantbacktest._1_data_preparation import save_dataframe_to_csv
-from quantbacktest._3_performance_evaluation import evaluate_performance
+from _helper_functions import find_dataframe_value_with_keywords, find_price, \
+    calculate_portfolio_value, calculate_relative_gross_exposure
+from _1_data_preparation import save_dataframe_to_csv
+from _3_performance_evaluation import evaluate_performance
 
 
 def initialize_trading_journal():
@@ -635,7 +635,42 @@ def execute_strategy_multi_asset(
         )
 
         if float_price is not None and float_price > 0:
-            if row['signal_type'] == "BUY":
+            if dict_strategy_hyperparameters['boolean_percentage_in_signal_table']:
+                if len(df_trading_journal) > 0:
+                    percentage_that_is_still_missing = row['percentage_to_be_bought'] - (
+                        (float_price * df_trading_journal['Dict of assets in portfolio'].iloc[-1][string_crypto_key]) / calculate_portfolio_value(
+                            df_prices=df_prices,
+                            dict_of_assets_in_portfolio=df_trading_journal['Dict of assets in portfolio'].iloc[-1],
+                            datetime_datetime=index[0],
+                            dict_constraints=dict_constraints,
+                            dict_display_options=dict_display_options,
+                            int_rounding_accuracy=dict_general_settings['int_rounding_decimal_places'],
+                            float_cash_value=df_trading_journal['Cash'].iloc[-1],
+                            boolean_gross_exposure=False
+                        )
+                    )
+                    float_number_to_be_bought = round(
+                        (
+                            (df_trading_journal.iloc[-1]['Portfolio value'] * percentage_that_is_still_missing) - dict_constraints['float_minimum_cash']
+                        ) / float_price,
+                        dict_general_settings['int_rounding_decimal_places_for_security_quantities']
+                    )
+                else:
+                    percentage_that_is_still_missing = row['percentage_to_be_bought']
+                    float_number_to_be_bought = round(
+                        (
+                            (float_budget_in_usd * percentage_that_is_still_missing) - dict_constraints['float_minimum_cash']
+                        ) / float_price,
+                        dict_general_settings['int_rounding_decimal_places_for_security_quantities']
+                    )
+                if float_number_to_be_bought > 0:
+                    boolean_buy = True
+                elif float_number_to_be_bought < 0:
+                    boolean_buy = False
+                else:
+                    boolean_buy = None
+
+            elif row['signal_type'] == "BUY":
                 boolean_buy = True
 
                 # Check if minimum is already crossed
@@ -655,22 +690,13 @@ def execute_strategy_multi_asset(
                     except:
                         pass
 
-                    if dict_strategy_hyperparameters['boolean_percentage_in_signal_table']:
-                        float_number_to_be_bought = round(
-                            (
-                                (df_trading_journal.iloc[-1]['Portfolio value'] * row['percentage_to_be_bought']) - dict_constraints['float_minimum_cash']
-                            ) / float_price,
-                            dict_general_settings['int_rounding_decimal_places_for_security_quantities']
-                        )
-                        print('BUY CORRECT', float_number_to_be_bought)
-                    else:
-                        float_number_to_be_bought = round(
-                            (
-                                float_budget_in_usd
-                                - dict_constraints['float_minimum_cash']
-                            ) / float_price,
-                            dict_general_settings['int_rounding_decimal_places_for_security_quantities']
-                        )
+                    float_number_to_be_bought = round(
+                        (
+                            float_budget_in_usd
+                            - dict_constraints['float_minimum_cash']
+                        ) / float_price,
+                        dict_general_settings['int_rounding_decimal_places_for_security_quantities']
+                    )
 
                 else:
                     float_number_to_be_bought = None
@@ -690,25 +716,15 @@ def execute_strategy_multi_asset(
                         )
                     ) is None
                 ):
-                    if dict_strategy_hyperparameters['boolean_percentage_in_signal_table']:
-                        float_number_to_be_bought = round(
-                            (
-                                (df_trading_journal.iloc[-1]['Portfolio value'] * row['percentage_to_be_bought'])
-                            ) / float_price,
-                            dict_general_settings['int_rounding_decimal_places_for_security_quantities']
+                    float_number_to_be_bought = (-1) * (
+                        find_dataframe_value_with_keywords(
+                            df_trading_journal,
+                            search_term_1=string_crypto_key,
+                            search_column_name_1='Asset',
+                            output_column_name='Exposure (number)',
+                            first_last_or_all_elements='Last'
                         )
-                        print('SELL CORRECT', float_number_to_be_bought)
-                    else:
-                        float_number_to_be_bought = (-1) * (
-                            find_dataframe_value_with_keywords(
-                                df_trading_journal,
-                                search_term_1=string_crypto_key,
-                                search_column_name_1='Asset',
-                                output_column_name='Exposure (number)',
-                                first_last_or_all_elements='Last'
-                            )
-                        )
-
+                    )
                 else:
                     float_number_to_be_bought = None
 
@@ -764,12 +780,6 @@ def execute_strategy_multi_asset(
         'dict_comments': dict_comments
     }
 
-    save_dataframe_to_csv(
-        df_trading_journal,
-        'trading_journal',
-        string_directory=dict_display_options['string_results_directory'],
-    )
-
     return dict_return
 
 def execute_strategy_white_noise(
@@ -873,12 +883,6 @@ def execute_strategy_white_noise(
         'dict_comments': ''
     }
 
-    save_dataframe_to_csv(
-        df_trading_journal,
-        'trading_journal',
-        string_directory=dict_display_options['string_results_directory'],
-    )
-
     return dict_return
 
 def execute_strategy_ma_crossover(
@@ -1029,12 +1033,6 @@ def execute_strategy_ma_crossover(
         'dict_comments': dict_comments
     }
 
-    save_dataframe_to_csv(
-        df_trading_journal,
-        'trading_journal',
-        string_directory=dict_display_options['string_results_directory'],
-    )
-
     return dict_return
 
 def test_strategy(
