@@ -21,11 +21,11 @@ from datetime import datetime, timedelta
 # consistent file versioning when saving the results as a CSV file.
 import os
 
-from quantbacktest._1_data_preparation import save_dataframe_to_csv
-from quantbacktest._3_individual_metrics import calculate_volatility, calculate_roi, \
+from _1_data_preparation import save_dataframe_to_csv
+from _3_individual_metrics import calculate_volatility, calculate_roi, \
     calculate_sharpe_ratio, calculate_maximum_drawdown, \
     calculate_transaction_cost, calculate_beta, calculate_alpha
-from quantbacktest._helper_functions import find_dataframe_value_with_keywords, find_price, \
+from _helper_functions import find_dataframe_value_with_keywords, find_price, \
     alternative_date_finder, calculate_portfolio_value, datetime_to_string, \
     add_time_column_to_dataframe_from_string
 
@@ -470,7 +470,7 @@ def evaluate_performance(
 
         save_dataframe_to_csv(
             df_daily_returns,
-            string_name='df_daily_returns',
+            string_name='daily_returns',
             string_directory=dict_display_options['string_results_directory'],
         )
 
